From c290c11da52964ada722bb90bd60e09945ba5347 Mon Sep 17 00:00:00 2001
From: Marti Raudsepp <marti@juffo.org>
Date: Wed, 7 Nov 2012 22:01:33 +0200
Subject: [PATCH] Fix CSRF verification in /admin/mergeorg/ and /admin/purge/

All templates using {% csrf_token %} need to be rendered with a
RequestContext.

This reverts most of commit 58a08f25901079c309d0713223e12c223b413d2c

Also permit POST requests to /search/ -- these aren't relevant to the
site itself, but this used to be allowed before.
---
 pgweb/core/views.py                | 7 +++----
 pgweb/search/views.py              | 2 ++
 templates/core/admin_mergeorg.html | 2 +-
 templates/core/admin_purge.html    | 2 +-
 4 files changed, 7 insertions(+), 6 deletions(-)

diff --git a/pgweb/core/views.py b/pgweb/core/views.py
index 3118e7f..9684846 100644
--- a/pgweb/core/views.py
+++ b/pgweb/core/views.py
@@ -31,6 +31,7 @@ from survey.models import Survey
 # models and forms needed for core objects
 from models import Organisation
 from forms import OrganisationForm, MergeOrgsForm
+from django.template.context import RequestContext
 
 # Front page view
 @cache(minutes=10)
@@ -185,7 +186,6 @@ def admin_pending(request):
 # Purge objects from varnish, for the admin pages
 @login_required
 @user_passes_test(lambda u: u.is_staff)
-@csrf_exempt
 def admin_purge(request):
 	if request.method == 'POST':
 		url = request.POST['url']
@@ -205,7 +205,7 @@ def admin_purge(request):
 	return render_to_response('core/admin_purge.html', {
 			'purge_completed': completed,
 			'latest_purges': latest,
-			})
+			}, RequestContext(request))
 
 @ssl_required
 @csrf_exempt
@@ -226,7 +226,6 @@ def api_varnish_purge(request):
 @login_required
 @user_passes_test(lambda u: u.is_superuser)
 @transaction.commit_on_success
-@csrf_exempt
 def admin_mergeorg(request):
 	if request.method == 'POST':
 		form = MergeOrgsForm(data=request.POST)
@@ -257,4 +256,4 @@ def admin_mergeorg(request):
 
 	return render_to_response('core/admin_mergeorg.html', {
 			'form': form,
-    })
+    }, RequestContext(request))
diff --git a/pgweb/search/views.py b/pgweb/search/views.py
index 265dfeb..0390f14 100644
--- a/pgweb/search/views.py
+++ b/pgweb/search/views.py
@@ -1,5 +1,6 @@
 from django.shortcuts import render_to_response, get_object_or_404
 from django.http import HttpResponse, Http404, HttpResponseRedirect
+from django.views.decorators.csrf import csrf_exempt
 from django.conf import settings
 
 from pgweb.util.decorators import cache
@@ -37,6 +38,7 @@ def generate_pagelinks(pagenum, totalpages, querystring):
 		yield '<a href="%s&p=%s">Next</a>' % (querystring, pagenum+1)
 
 
+@csrf_exempt
 @cache(minutes=15)
 def search(request):
 	# Perform a general web search
diff --git a/templates/core/admin_mergeorg.html b/templates/core/admin_mergeorg.html
index 6adf2b1..cde62ba 100644
--- a/templates/core/admin_mergeorg.html
+++ b/templates/core/admin_mergeorg.html
@@ -10,7 +10,7 @@
 {%block content%}
 <div id="content-main">
 <h1>Merge organisations</h1>
-<form method="post" action=".">
+<form method="post" action=".">{% csrf_token %}
 <table>
 {{form.as_table}}
 </table>
diff --git a/templates/core/admin_purge.html b/templates/core/admin_purge.html
index 1405570..d7e91f1 100644
--- a/templates/core/admin_purge.html
+++ b/templates/core/admin_purge.html
@@ -17,7 +17,7 @@
   </div>
 {%endif%}
 
- <form method="POST" action=".">
+ <form method="POST" action=".">{% csrf_token %}
 URL (regex): <input type="text" name="url">
   <input type="submit" value="Purge" />
  </form>
-- 
1.8.0

